@@ -1,5 +1,5 @@
 /* User-registered handlers for specific `ioctl' requests.
-   Copyright (C) 1993,94,95,96,97,2000,01 Free Software Foundation, Inc.
+   Copyright (C) 1993-2017 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -54,7 +54,7 @@ extern int hurd_register_ioctl_handler (int first_request, int last_request,
 
 #define	_HURD_HANDLE_IOCTLS_1(handler, first, last, moniker)		      \
   static const struct ioctl_handler handler##_ioctl_handler##moniker	      \
-  	__attribute__ ((__unused__)) =					      \
+	__attribute__ ((__unused__)) =					      \
     { _IOC_NOTYPE (first), _IOC_NOTYPE (last),				      \
 	(ioctl_handler_t) (handler), NULL };				      \
   text_set_element (_hurd_ioctl_handler_lists,				      \
@@ -68,6 +68,11 @@ extern int hurd_register_ioctl_handler (int first_request, int last_request,
   _HURD_HANDLE_IOCTLS_1 (handler, ioctl, ioctl, ioctl##_only)
 
 
+/* Install a new CTTYID port, atomically updating the dtable appropriately.
+   This consumes the send right passed in.  */
+
+void _hurd_locked_install_cttyid (mach_port_t cttyid);
+
 /* Lookup the handler for the given ioctl request.  */
 
 ioctl_handler_t _hurd_lookup_ioctl_handler (int request);
