@@ -1,5 +1,5 @@
 /* Tables for conversion from and to IBM856.
-   Copyright (C) 2000, 2001 Free Software Foundation, Inc.
+   Copyright (C) 2000-2017 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
    Contributed by Masahide Washizawa <washi@yamato.ibm.co.jp>, 2000.
 
@@ -14,9 +14,10 @@
    Lesser General Public License for more details.
 
    You should have received a copy of the GNU Lesser General Public
-   License along with the GNU C Library; if not, write to the Free
-   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-   02111-1307 USA.  */
+   License along with the GNU C Library; if not, see
+   <http://www.gnu.org/licenses/>.  */
+
+#include <stdint.h>
 
 static const uint32_t to_ucs4[256] =
 {
@@ -78,66 +79,66 @@ static const uint32_t to_ucs4[256] =
 
 static const struct gap from_idx[] =
 {
-  { start: 0x0000, end: 0x007f, idx:      0 },
-  { start: 0x00a0, end: 0x00a0, idx:    -32 },
-  { start: 0x00a2, end: 0x00a9, idx:    -33 },
-  { start: 0x00ab, end: 0x00ae, idx:    -34 },
-  { start: 0x00b0, end: 0x00b6, idx:    -35 },
-  { start: 0x00b8, end: 0x00b9, idx:    -36 },
-  { start: 0x00bb, end: 0x00be, idx:    -37 },
-  { start: 0x00d7, end: 0x00d7, idx:    -61 },
-  { start: 0x00f7, end: 0x00f7, idx:    -92 },
-  { start: 0x05d0, end: 0x05ea, idx:  -1332 },
-  { start: 0x2017, end: 0x2017, idx:  -8032 },
-  { start: 0x2022, end: 0x2022, idx:  -8042 },
-  { start: 0x203c, end: 0x203c, idx:  -8067 },
-  { start: 0x203e, end: 0x203e, idx:  -8068 },
-  { start: 0x2190, end: 0x2195, idx:  -8405 },
-  { start: 0x21a8, end: 0x21a8, idx:  -8423 },
-  { start: 0x221f, end: 0x221f, idx:  -8541 },
-  { start: 0x2302, end: 0x2302, idx:  -8767 },
-  { start: 0x2500, end: 0x2500, idx:  -9276 },
-  { start: 0x2502, end: 0x2502, idx:  -9277 },
-  { start: 0x250c, end: 0x250c, idx:  -9286 },
-  { start: 0x2510, end: 0x2510, idx:  -9289 },
-  { start: 0x2514, end: 0x2514, idx:  -9292 },
-  { start: 0x2518, end: 0x2518, idx:  -9295 },
-  { start: 0x251c, end: 0x251c, idx:  -9298 },
-  { start: 0x2524, end: 0x2524, idx:  -9305 },
-  { start: 0x252c, end: 0x252c, idx:  -9312 },
-  { start: 0x2534, end: 0x2534, idx:  -9319 },
-  { start: 0x253c, end: 0x253c, idx:  -9326 },
-  { start: 0x2550, end: 0x2551, idx:  -9345 },
-  { start: 0x2554, end: 0x2554, idx:  -9347 },
-  { start: 0x2557, end: 0x2557, idx:  -9349 },
-  { start: 0x255a, end: 0x255a, idx:  -9351 },
-  { start: 0x255d, end: 0x255d, idx:  -9353 },
-  { start: 0x2560, end: 0x2560, idx:  -9355 },
-  { start: 0x2563, end: 0x2563, idx:  -9357 },
-  { start: 0x2566, end: 0x2566, idx:  -9359 },
-  { start: 0x2569, end: 0x2569, idx:  -9361 },
-  { start: 0x256c, end: 0x256c, idx:  -9363 },
-  { start: 0x2580, end: 0x2580, idx:  -9382 },
-  { start: 0x2584, end: 0x2584, idx:  -9385 },
-  { start: 0x2588, end: 0x2588, idx:  -9388 },
-  { start: 0x2591, end: 0x2593, idx:  -9396 },
-  { start: 0x25a0, end: 0x25a0, idx:  -9408 },
-  { start: 0x25ac, end: 0x25ac, idx:  -9419 },
-  { start: 0x25b2, end: 0x25b2, idx:  -9424 },
-  { start: 0x25ba, end: 0x25ba, idx:  -9431 },
-  { start: 0x25bc, end: 0x25bc, idx:  -9432 },
-  { start: 0x25c4, end: 0x25c4, idx:  -9439 },
-  { start: 0x25cb, end: 0x25cb, idx:  -9445 },
-  { start: 0x25d8, end: 0x25d9, idx:  -9457 },
-  { start: 0x263a, end: 0x263c, idx:  -9553 },
-  { start: 0x2640, end: 0x2640, idx:  -9556 },
-  { start: 0x2642, end: 0x2642, idx:  -9557 },
-  { start: 0x2660, end: 0x2660, idx:  -9586 },
-  { start: 0x2663, end: 0x2663, idx:  -9588 },
-  { start: 0x2665, end: 0x2666, idx:  -9589 },
-  { start: 0x266a, end: 0x266b, idx:  -9592 },
-  { start: 0xffe8, end: 0xffee, idx: -65268 },
-  { start: 0xffff, end: 0xffff, idx:      0 }
+  { .start = 0x0000, .end = 0x007f, .idx =      0 },
+  { .start = 0x00a0, .end = 0x00a0, .idx =    -32 },
+  { .start = 0x00a2, .end = 0x00a9, .idx =    -33 },
+  { .start = 0x00ab, .end = 0x00ae, .idx =    -34 },
+  { .start = 0x00b0, .end = 0x00b6, .idx =    -35 },
+  { .start = 0x00b8, .end = 0x00b9, .idx =    -36 },
+  { .start = 0x00bb, .end = 0x00be, .idx =    -37 },
+  { .start = 0x00d7, .end = 0x00d7, .idx =    -61 },
+  { .start = 0x00f7, .end = 0x00f7, .idx =    -92 },
+  { .start = 0x05d0, .end = 0x05ea, .idx =  -1332 },
+  { .start = 0x2017, .end = 0x2017, .idx =  -8032 },
+  { .start = 0x2022, .end = 0x2022, .idx =  -8042 },
+  { .start = 0x203c, .end = 0x203c, .idx =  -8067 },
+  { .start = 0x203e, .end = 0x203e, .idx =  -8068 },
+  { .start = 0x2190, .end = 0x2195, .idx =  -8405 },
+  { .start = 0x21a8, .end = 0x21a8, .idx =  -8423 },
+  { .start = 0x221f, .end = 0x221f, .idx =  -8541 },
+  { .start = 0x2302, .end = 0x2302, .idx =  -8767 },
+  { .start = 0x2500, .end = 0x2500, .idx =  -9276 },
+  { .start = 0x2502, .end = 0x2502, .idx =  -9277 },
+  { .start = 0x250c, .end = 0x250c, .idx =  -9286 },
+  { .start = 0x2510, .end = 0x2510, .idx =  -9289 },
+  { .start = 0x2514, .end = 0x2514, .idx =  -9292 },
+  { .start = 0x2518, .end = 0x2518, .idx =  -9295 },
+  { .start = 0x251c, .end = 0x251c, .idx =  -9298 },
+  { .start = 0x2524, .end = 0x2524, .idx =  -9305 },
+  { .start = 0x252c, .end = 0x252c, .idx =  -9312 },
+  { .start = 0x2534, .end = 0x2534, .idx =  -9319 },
+  { .start = 0x253c, .end = 0x253c, .idx =  -9326 },
+  { .start = 0x2550, .end = 0x2551, .idx =  -9345 },
+  { .start = 0x2554, .end = 0x2554, .idx =  -9347 },
+  { .start = 0x2557, .end = 0x2557, .idx =  -9349 },
+  { .start = 0x255a, .end = 0x255a, .idx =  -9351 },
+  { .start = 0x255d, .end = 0x255d, .idx =  -9353 },
+  { .start = 0x2560, .end = 0x2560, .idx =  -9355 },
+  { .start = 0x2563, .end = 0x2563, .idx =  -9357 },
+  { .start = 0x2566, .end = 0x2566, .idx =  -9359 },
+  { .start = 0x2569, .end = 0x2569, .idx =  -9361 },
+  { .start = 0x256c, .end = 0x256c, .idx =  -9363 },
+  { .start = 0x2580, .end = 0x2580, .idx =  -9382 },
+  { .start = 0x2584, .end = 0x2584, .idx =  -9385 },
+  { .start = 0x2588, .end = 0x2588, .idx =  -9388 },
+  { .start = 0x2591, .end = 0x2593, .idx =  -9396 },
+  { .start = 0x25a0, .end = 0x25a0, .idx =  -9408 },
+  { .start = 0x25ac, .end = 0x25ac, .idx =  -9419 },
+  { .start = 0x25b2, .end = 0x25b2, .idx =  -9424 },
+  { .start = 0x25ba, .end = 0x25ba, .idx =  -9431 },
+  { .start = 0x25bc, .end = 0x25bc, .idx =  -9432 },
+  { .start = 0x25c4, .end = 0x25c4, .idx =  -9439 },
+  { .start = 0x25cb, .end = 0x25cb, .idx =  -9445 },
+  { .start = 0x25d8, .end = 0x25d9, .idx =  -9457 },
+  { .start = 0x263a, .end = 0x263c, .idx =  -9553 },
+  { .start = 0x2640, .end = 0x2640, .idx =  -9556 },
+  { .start = 0x2642, .end = 0x2642, .idx =  -9557 },
+  { .start = 0x2660, .end = 0x2660, .idx =  -9586 },
+  { .start = 0x2663, .end = 0x2663, .idx =  -9588 },
+  { .start = 0x2665, .end = 0x2666, .idx =  -9589 },
+  { .start = 0x266a, .end = 0x266b, .idx =  -9592 },
+  { .start = 0xffe8, .end = 0xffee, .idx = -65268 },
+  { .start = 0xffff, .end = 0xffff, .idx =      0 }
 };
 
 static const char from_ucs4[] =
