@@ -1,4 +1,4 @@
-/* Copyright (C) 1991-2015 Free Software Foundation, Inc.
+/* Copyright (C) 1991-2017 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -22,9 +22,7 @@
 
 /* Create FILE with protections MODE.  */
 int
-creat64 (file, mode)
-     const char *file;
-     mode_t mode;
+creat64 (const char *file, mode_t mode)
 {
   return __open64 (file, O_WRONLY|O_CREAT|O_TRUNC, mode);
 }
