@@ -1,4 +1,4 @@
-/* Copyright (C) 1993-2015 Free Software Foundation, Inc.
+/* Copyright (C) 1993-2017 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -35,11 +35,8 @@
 
 #include <kernel-features.h>
 
-FILE*
-freopen (filename, mode, fp)
-     const char* filename;
-     const char* mode;
-     FILE* fp;
+FILE *
+freopen (const char *filename, const char *mode, FILE *fp)
 {
   FILE *result;
   CHECK_FILE (fp, NULL);
