@@ -1,4 +1,4 @@
-/* Copyright (C) 1993, 1996, 1997 Free Software Foundation, Inc.
+/* Copyright (C) 1993-2017 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -30,7 +30,7 @@
 #undef getchar_unlocked
 
 int
-getchar_unlocked ()
+getchar_unlocked (void)
 {
   return _IO_getc_unlocked (_IO_stdin);
 }
