@@ -1,4 +1,4 @@
-/* Copyright (C) 1993-2015 Free Software Foundation, Inc.
+/* Copyright (C) 1993-2017 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -29,8 +29,7 @@
 #include <limits.h>
 
 int
-_IO_puts (str)
-     const char *str;
+_IO_puts (const char *str)
 {
   int result = EOF;
   _IO_size_t len = strlen (str);
