@@ -1,4 +1,4 @@
-/* Copyright (C) 1993-2014 Free Software Foundation, Inc.
+/* Copyright (C) 1993-2017 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
    Written by Per Bothner <bothner@cygnus.com>.
 
@@ -41,6 +41,7 @@
 #include <string.h>
 #include <errno.h>
 #include <stdlib.h>
+#include <unistd.h>
 #ifndef errno
 extern int errno;
 #endif
@@ -113,8 +114,7 @@ extern int errno;
 
 void
 attribute_compat_text_section
-_IO_old_file_init (fp)
-     struct _IO_FILE_plus *fp;
+_IO_old_file_init_internal (struct _IO_FILE_plus *fp)
 {
   /* POSIX.1 allows another file handle to be used to change the position
      of our file descriptor.  Hence we actually don't know the actual
@@ -138,10 +138,17 @@ _IO_old_file_init (fp)
 #endif
 }
 
+void
+attribute_compat_text_section
+_IO_old_file_init (struct _IO_FILE_plus *fp)
+{
+  IO_set_accept_foreign_vtables (&_IO_vtable_check);
+  _IO_old_file_init_internal (fp);
+}
+
 int
 attribute_compat_text_section
-_IO_old_file_close_it (fp)
-     _IO_FILE *fp;
+_IO_old_file_close_it (_IO_FILE *fp)
 {
   int write_status, close_status;
   if (!_IO_file_is_open (fp))
@@ -169,9 +176,7 @@ _IO_old_file_close_it (fp)
 
 void
 attribute_compat_text_section
-_IO_old_file_finish (fp, dummy)
-     _IO_FILE *fp;
-     int dummy;
+_IO_old_file_finish (_IO_FILE *fp, int dummy)
 {
   if (_IO_file_is_open (fp))
     {
@@ -184,10 +189,7 @@ _IO_old_file_finish (fp, dummy)
 
 _IO_FILE *
 attribute_compat_text_section
-_IO_old_file_fopen (fp, filename, mode)
-     _IO_FILE *fp;
-     const char *filename;
-     const char *mode;
+_IO_old_file_fopen (_IO_FILE *fp, const char *filename, const char *mode)
 {
   int oflags = 0, omode;
   int read_write, fdesc;
@@ -234,9 +236,7 @@ _IO_old_file_fopen (fp, filename, mode)
 
 _IO_FILE *
 attribute_compat_text_section
-_IO_old_file_attach (fp, fd)
-     _IO_FILE *fp;
-     int fd;
+_IO_old_file_attach (_IO_FILE *fp, int fd)
 {
   if (_IO_file_is_open (fp))
     return NULL;
@@ -254,10 +254,7 @@ _IO_old_file_attach (fp, fd)
 
 _IO_FILE *
 attribute_compat_text_section
-_IO_old_file_setbuf (fp, p, len)
-     _IO_FILE *fp;
-     char *p;
-     _IO_ssize_t len;
+_IO_old_file_setbuf (_IO_FILE *fp, char *p, _IO_ssize_t len)
 {
     if (_IO_default_setbuf (fp, p, len) == NULL)
       return NULL;
@@ -276,10 +273,7 @@ static int old_do_write (_IO_FILE *, const char *, _IO_size_t);
 
 int
 attribute_compat_text_section
-_IO_old_do_write (fp, data, to_do)
-     _IO_FILE *fp;
-     const char *data;
-     _IO_size_t to_do;
+_IO_old_do_write (_IO_FILE *fp, const char *data, _IO_size_t to_do)
 {
   return (to_do == 0 || (_IO_size_t) old_do_write (fp, data, to_do) == to_do)
 	 ? 0 : EOF;
@@ -287,10 +281,7 @@ _IO_old_do_write (fp, data, to_do)
 
 static int
 attribute_compat_text_section
-old_do_write (fp, data, to_do)
-     _IO_FILE *fp;
-     const char *data;
-     _IO_size_t to_do;
+old_do_write (_IO_FILE *fp, const char *data, _IO_size_t to_do)
 {
   _IO_size_t count;
   if (fp->_flags & _IO_IS_APPENDING)
@@ -313,15 +304,14 @@ old_do_write (fp, data, to_do)
     fp->_cur_column = _IO_adjust_column (fp->_cur_column - 1, data, count) + 1;
   _IO_setg (fp, fp->_IO_buf_base, fp->_IO_buf_base, fp->_IO_buf_base);
   fp->_IO_write_base = fp->_IO_write_ptr = fp->_IO_buf_base;
-  fp->_IO_write_end = ((fp->_flags & (_IO_LINE_BUF+_IO_UNBUFFERED))
+  fp->_IO_write_end = ((fp->_flags & (_IO_LINE_BUF | _IO_UNBUFFERED))
 		       ? fp->_IO_buf_base : fp->_IO_buf_end);
   return count;
 }
 
 int
 attribute_compat_text_section
-_IO_old_file_underflow (fp)
-     _IO_FILE *fp;
+_IO_old_file_underflow (_IO_FILE *fp)
 {
   _IO_ssize_t count;
 #if 0
@@ -385,9 +375,7 @@ _IO_old_file_underflow (fp)
 
 int
 attribute_compat_text_section
-_IO_old_file_overflow (f, ch)
-      _IO_FILE *f;
-      int ch;
+_IO_old_file_overflow (_IO_FILE *f, int ch)
 {
   if (f->_flags & _IO_NO_WRITES) /* SET ERROR */
     {
@@ -418,7 +406,7 @@ _IO_old_file_overflow (f, ch)
       f->_IO_write_end = f->_IO_buf_end;
       f->_IO_read_base = f->_IO_read_ptr = f->_IO_read_end;
 
-      if (f->_flags & (_IO_LINE_BUF+_IO_UNBUFFERED))
+      if (f->_flags & (_IO_LINE_BUF | _IO_UNBUFFERED))
 	f->_IO_write_end = f->_IO_write_ptr;
       f->_flags |= _IO_CURRENTLY_PUTTING;
     }
@@ -437,8 +425,7 @@ _IO_old_file_overflow (f, ch)
 
 int
 attribute_compat_text_section
-_IO_old_file_sync (fp)
-     _IO_FILE *fp;
+_IO_old_file_sync (_IO_FILE *fp)
 {
   _IO_ssize_t delta;
   int retval = 0;
@@ -472,11 +459,7 @@ _IO_old_file_sync (fp)
 
 _IO_off64_t
 attribute_compat_text_section
-_IO_old_file_seekoff (fp, offset, dir, mode)
-     _IO_FILE *fp;
-     _IO_off64_t offset;
-     int dir;
-     int mode;
+_IO_old_file_seekoff (_IO_FILE *fp, _IO_off64_t offset, int dir, int mode)
 {
   _IO_off_t result;
   _IO_off64_t delta, new_offset;
@@ -659,10 +642,7 @@ resync:
 
 _IO_ssize_t
 attribute_compat_text_section
-_IO_old_file_write (f, data, n)
-     _IO_FILE *f;
-     const void *data;
-     _IO_ssize_t n;
+_IO_old_file_write (_IO_FILE *f, const void *data, _IO_ssize_t n)
 {
   _IO_ssize_t to_do = n;
   while (to_do > 0)
@@ -684,10 +664,7 @@ _IO_old_file_write (f, data, n)
 
 _IO_size_t
 attribute_compat_text_section
-_IO_old_file_xsputn (f, data, n)
-     _IO_FILE *f;
-     const void *data;
-     _IO_size_t n;
+_IO_old_file_xsputn (_IO_FILE *f, const void *data, _IO_size_t n)
 {
   const char *s = (char *) data;
   _IO_size_t to_do = n;
@@ -776,7 +753,7 @@ _IO_old_file_xsputn (f, data, n)
 }
 
 
-const struct _IO_jump_t _IO_old_file_jumps =
+const struct _IO_jump_t _IO_old_file_jumps libio_vtable =
 {
   JUMP_INIT_DUMMY,
   JUMP_INIT(finish, _IO_old_file_finish),
