@@ -1,4 +1,4 @@
-/* Copyright (C) 1991-2014 Free Software Foundation, Inc.
+/* Copyright (C) 1991-2017 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -19,9 +19,7 @@
 #include <wchar.h>
 
 wint_t
-putwc (wc, fp)
-     wchar_t wc;
-     _IO_FILE *fp;
+putwc (wchar_t wc, _IO_FILE *fp)
 {
   wint_t result;
   CHECK_FILE (fp, WEOF);
