@@ -1,5 +1,5 @@
 /* Common definitions for libm tests for non-inline functions.
-   Copyright (C) 1997-2015 Free Software Foundation, Inc.
+   Copyright (C) 1997-2017 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -16,6 +16,9 @@
    License along with the GNU C Library; if not, see
    <http://www.gnu.org/licenses/>.  */
 
+#define TEST_INLINE 0
+#define TEST_EXCEPTIONS 1
+
 #ifndef __NO_MATH_INLINES
 # define __NO_MATH_INLINES
 #endif
