@@ -1,4 +1,4 @@
-/* Copyright (C) 1991,1995,1996,1997,2000,2001 Free Software Foundation, Inc.
+/* Copyright (C) 1991-2017 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -22,9 +22,7 @@
    The result is null-terminated if LEN is large enough for the full
    name and the terminator.  */
 int
-__gethostname (name, len)
-     char *name;
-     size_t len;
+__gethostname (char *name, size_t len)
 {
   __set_errno (ENOSYS);
   return -1;
@@ -32,4 +30,3 @@ __gethostname (name, len)
 stub_warning (gethostname)
 
 weak_alias (__gethostname, gethostname)
-#include <stub-tag.h>
