@@ -1,4 +1,4 @@
-/* Copyright (C) 1991, 1995, 1996, 1997, 2004 Free Software Foundation, Inc.
+/* Copyright (C) 1991-2017 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -23,8 +23,7 @@
 void *sstk (int increment) __THROW;
 
 void *
-sstk (increment)
-     int increment;
+sstk (int increment)
 {
   __set_errno (ENOSYS);
   return (void *) -1;
