@@ -1,4 +1,4 @@
-/* Copyright (C) 2002-2014 Free Software Foundation, Inc.
+/* Copyright (C) 2002-2017 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
    Contributed by Ulrich Drepper <drepper@redhat.com>, 2002.
 
@@ -21,8 +21,7 @@
 
 
 void
-__pthread_exit (value)
-     void *value;
+__pthread_exit (void *value)
 {
   THREAD_SETMEM (THREAD_SELF, result, value);
 
