@@ -64,14 +64,9 @@
  * SOFTWARE.
  */
 
-#if defined(LIBC_SCCS) && !defined(lint)
-static const char sccsid[] = "@(#)res_init.c	8.1 (Berkeley) 6/7/93";
-static const char rcsid[] = "$BINDId: res_init.c,v 8.16 2000/05/09 07:10:12 vixie Exp $";
-#endif /* LIBC_SCCS and not lint */
-
 #include <ctype.h>
 #include <netdb.h>
-#include <resolv.h>
+#include <resolv/resolv-internal.h>
 #include <stdio.h>
 #include <stdio_ext.h>
 #include <stdlib.h>
@@ -86,30 +81,21 @@ static const char rcsid[] = "$BINDId: res_init.c,v 8.16 2000/05/09 07:10:12 vixi
 #include <sys/socket.h>
 #include <sys/time.h>
 #include <sys/types.h>
+#include <inet/net-internal.h>
 
 #include <not-cancel.h>
 
 /* Options.  Should all be left alone. */
-#define RESOLVSORT
-#define RFC1535
 /* #undef DEBUG */
 
 static void res_setoptions (res_state, const char *, const char *)
      internal_function;
 
-#ifdef RESOLVSORT
 static const char sort_mask_chars[] = "/&";
 #define ISSORTMASK(ch) (strchr(sort_mask_chars, ch) != NULL)
 static u_int32_t net_mask (struct in_addr) __THROW;
-#endif
 
-#if !defined(isascii)	/* XXX - could be a function */
-# define isascii(c) (!(c & 0200))
-#endif
-
-#ifdef _LIBC
 unsigned long long int __res_initstamp attribute_hidden;
-#endif
 
 /*
  * Resolver state default settings.
@@ -118,21 +104,7 @@ unsigned long long int __res_initstamp attribute_hidden;
 /*
  * Set up default settings.  If the configuration file exist, the values
  * there will have precedence.  Otherwise, the server address is set to
- * INADDR_ANY and the default domain name comes from the gethostname().
- *
- * An interrim version of this code (BIND 4.9, pre-4.4BSD) used 127.0.0.1
- * rather than INADDR_ANY ("0.0.0.0") as the default name server address
- * since it was noted that INADDR_ANY actually meant ``the first interface
- * you "ifconfig"'d at boot time'' and if this was a SLIP or PPP interface,
- * it had to be "up" in order for you to reach your own name server.  It
- * was later decided that since the recommended practice is to always
- * install local static routes through 127.0.0.1 for all your network
- * interfaces, that we could solve this problem without a code change.
- *
- * The configuration file should always be used, since it is the only way
- * to specify a default domain.  If you are running a server on your local
- * machine, you should say "nameserver 0.0.0.0" or "nameserver 127.0.0.1"
- * in the configuration file.
+ * INADDR_LOOPBACK and the default domain name comes from gethostname.
  *
  * Return 0 if completes successfully, -1 on error
  */
@@ -142,9 +114,7 @@ res_ninit(res_state statp) {
 
 	return (__res_vinit(statp, 0));
 }
-#ifdef _LIBC
 libc_hidden_def (__res_ninit)
-#endif
 
 /* This function has to be reachable by res_data.c but not publically. */
 int
@@ -157,16 +127,9 @@ __res_vinit(res_state statp, int preinit) {
 	int have_serv6 = 0;
 	int haveenv = 0;
 	int havesearch = 0;
-#ifdef RESOLVSORT
 	int nsort = 0;
 	char *net;
-#endif
-#ifndef RFC1535
-	int dots;
-#endif
-#ifdef _LIBC
 	statp->_u._ext.initstamp = __res_initstamp;
-#endif
 
 	if (!preinit) {
 		statp->retrans = RES_TIMEOUT;
@@ -176,12 +139,13 @@ __res_vinit(res_state statp, int preinit) {
 	}
 
 	statp->nscount = 0;
+	statp->defdname[0] = '\0';
 	statp->ndots = 1;
 	statp->pfcode = 0;
 	statp->_vcsock = -1;
 	statp->_flags = 0;
-	statp->qhook = NULL;
-	statp->rhook = NULL;
+	statp->__glibc_unused_qhook = NULL;
+	statp->__glibc_unused_rhook = NULL;
 	statp->_u._ext.nscount = 0;
 	for (n = 0; n < MAXNS; n++)
 	    statp->_u._ext.nsaddrs[n] = NULL;
@@ -301,7 +265,6 @@ __res_vinit(res_state statp, int preinit) {
 			statp->nsaddr_list[nserv].sin_port =
 				htons(NAMESERVER_PORT);
 			nserv++;
-#ifdef _LIBC
 		    } else {
 			struct in6_addr a6;
 			char *el;
@@ -321,26 +284,12 @@ __res_vinit(res_state statp, int preinit) {
 				sa6->sin6_flowinfo = 0;
 				sa6->sin6_addr = a6;
 
-				if (__glibc_likely (el == NULL))
-				    sa6->sin6_scope_id = 0;
-				else {
-				    int try_numericscope = 1;
-				    if (IN6_IS_ADDR_LINKLOCAL (&a6)
-					|| IN6_IS_ADDR_MC_LINKLOCAL (&a6)) {
-					sa6->sin6_scope_id
-					  = __if_nametoindex (el + 1);
-					if (sa6->sin6_scope_id != 0)
-					    try_numericscope = 0;
-				    }
-
-				    if (try_numericscope) {
-					char *end;
-					sa6->sin6_scope_id
-					  = (uint32_t) strtoul (el + 1, &end,
-								10);
-					if (*end != '\0')
-					    sa6->sin6_scope_id = 0;
-				    }
+				sa6->sin6_scope_id = 0;
+				if (__glibc_likely (el != NULL)) {
+				  /* Ignore errors, for backwards
+				     compatibility.  */
+				  (void) __inet6_scopeid_pton
+				    (&a6, el + 1, &sa6->sin6_scope_id);
 				}
 
 				statp->nsaddr_list[nserv].sin_family = 0;
@@ -350,11 +299,9 @@ __res_vinit(res_state statp, int preinit) {
 				nserv++;
 			    }
 			}
-#endif
 		    }
 		    continue;
 		}
-#ifdef RESOLVSORT
 		if (MATCH(buf, "sortlist")) {
 		    struct in_addr a;
 
@@ -396,22 +343,17 @@ __res_vinit(res_state statp, int preinit) {
 		    }
 		    continue;
 		}
-#endif
 		if (MATCH(buf, "options")) {
 		    res_setoptions(statp, buf + sizeof("options") - 1, "conf");
 		    continue;
 		}
 	    }
 	    statp->nscount = nserv;
-#ifdef _LIBC
 	    if (have_serv6) {
 		/* We try IPv6 servers again.  */
 		statp->ipv6_unavail = false;
 	    }
-#endif
-#ifdef RESOLVSORT
 	    statp->nsort = nsort;
-#endif
 	    (void) fclose(fp);
 	}
 	if (__builtin_expect(statp->nscount == 0, 0)) {
@@ -431,29 +373,6 @@ __res_vinit(res_state statp, int preinit) {
 		*pp++ = statp->defdname;
 		*pp = NULL;
 
-#ifndef RFC1535
-		dots = 0;
-		for (cp = statp->defdname; *cp; cp++)
-			dots += (*cp == '.');
-
-		cp = statp->defdname;
-		while (pp < statp->dnsrch + MAXDFLSRCH) {
-			if (dots < LOCALDOMAINPARTS)
-				break;
-			cp = __rawmemchr(cp, '.') + 1;    /* we know there is one */
-			*pp++ = cp;
-			dots--;
-		}
-		*pp = NULL;
-#ifdef DEBUG
-		if (statp->options & RES_DEBUG) {
-			printf(";; res_init()... default dnsrch list:\n");
-			for (pp = statp->dnsrch; *pp; pp++)
-				printf(";;\t%s\n", *pp);
-			printf(";;\t..END..\n");
-		}
-#endif
-#endif /* !RFC1535 */
 	}
 
 	if ((cp = getenv("RES_OPTIONS")) != NULL)
@@ -518,12 +437,8 @@ res_setoptions(res_state statp, const char *options, const char *source) {
 		    unsigned long int flag;
 		  } options[] = {
 #define STRnLEN(str) str, sizeof (str) - 1
-		    { STRnLEN ("inet6"), 0, RES_USE_INET6 },
-		    { STRnLEN ("ip6-bytestring"), 0, RES_USEBSTRING },
-		    { STRnLEN ("no-ip6-dotint"), 0, RES_NOIP6DOTINT },
-		    { STRnLEN ("ip6-dotint"), 1, ~RES_NOIP6DOTINT },
+		    { STRnLEN ("inet6"), 0, DEPRECATED_RES_USE_INET6 },
 		    { STRnLEN ("rotate"), 0, RES_ROTATE },
-		    { STRnLEN ("no-check-names"), 0, RES_NOCHECKNAME },
 		    { STRnLEN ("edns0"), 0, RES_USE_EDNS0 },
 		    { STRnLEN ("single-request-reopen"), 0, RES_SNGLKUPREOP },
 		    { STRnLEN ("single-request"), 0, RES_SNGLKUP },
@@ -552,11 +467,10 @@ res_setoptions(res_state statp, const char *options, const char *source) {
 	}
 }
 
-#ifdef RESOLVSORT
 /* XXX - should really support CIDR which means explicit masks always. */
+/* XXX - should really use system's version of this */
 static u_int32_t
-net_mask(in)		/* XXX - should really use system's version of this */
-	struct in_addr in;
+net_mask (struct in_addr in)
 {
 	u_int32_t i = ntohl(in.s_addr);
 
@@ -566,15 +480,12 @@ net_mask(in)		/* XXX - should really use system's version of this */
 		return (htonl(IN_CLASSB_NET));
 	return (htonl(IN_CLASSC_NET));
 }
-#endif
 
 u_int
 res_randomid(void) {
 	return 0xffff & __getpid();
 }
-#ifdef _LIBC
 libc_hidden_def (__res_randomid)
-#endif
 
 
 /*
@@ -593,7 +504,7 @@ __res_iclose(res_state statp, bool free_addr) {
 		statp->_vcsock = -1;
 		statp->_flags &= ~(RES_F_VC | RES_F_CONN);
 	}
-	for (ns = 0; ns < statp->_u._ext.nscount; ns++)
+	for (ns = 0; ns < statp->nscount; ns++)
 		if (statp->_u._ext.nsaddrs[ns]) {
 			if (statp->_u._ext.nssocks[ns] != -1) {
 				close_not_cancel_no_status(statp->_u._ext.nssocks[ns]);
@@ -612,12 +523,8 @@ res_nclose(res_state statp)
 {
   __res_iclose (statp, true);
 }
-#ifdef _LIBC
 libc_hidden_def (__res_nclose)
-#endif
 
-#ifdef _LIBC
-# ifdef _LIBC_REENTRANT
 /* This is called when a thread is exiting to free resources held in _res.  */
 static void __attribute__ ((section ("__libc_thread_freeres_fn")))
 res_thread_freeres (void)
@@ -633,5 +540,3 @@ res_thread_freeres (void)
 }
 text_set_element (__libc_thread_subfreeres, res_thread_freeres);
 text_set_element (__libc_subfreeres, res_thread_freeres);
-# endif
-#endif
