@@ -1,4 +1,4 @@
-/* Copyright (C) 1991,95,96,97,2000,02 Free Software Foundation, Inc.
+/* Copyright (C) 1991-2017 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -23,13 +23,12 @@
    or user (as specified by WHO) is used.  A lower priority number means higher
    priority.  Priorities range from PRIO_MIN to PRIO_MAX.  */
 int
-getpriority (which, who)
-     enum __priority_which which;
-     id_t who;
+__getpriority (enum __priority_which which, id_t who)
 {
   __set_errno (ENOSYS);
   return -1;
 }
-libc_hidden_def (getpriority)
+libc_hidden_def (__getpriority)
+weak_alias (__getpriority, getpriority)
 
 stub_warning (getpriority)
