@@ -1,4 +1,4 @@
-/* Copyright (C) 1991,96,97,2002,2003,2004 Free Software Foundation, Inc.
+/* Copyright (C) 1991-2017 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -12,9 +12,8 @@
    Lesser General Public License for more details.
 
    You should have received a copy of the GNU Lesser General Public
-   License along with the GNU C Library; if not, write to the Free
-   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-   02111-1307 USA.  */
+   License along with the GNU C Library; if not, see
+   <http://www.gnu.org/licenses/>.  */
 
 #include <errno.h>
 #include <signal.h>
@@ -22,8 +21,7 @@
 
 /* Set all signals in SET.  */
 int
-sigfillset (set)
-     sigset_t *set;
+sigfillset (sigset_t *set)
 {
   if (set == NULL)
     {
