@@ -1,5 +1,5 @@
 /* Remove SIG from the calling process' signal mask.
-   Copyright (C) 1998-2013 Free Software Foundation, Inc.
+   Copyright (C) 1998-2017 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
    Contributed by Ulrich Drepper <drepper@cygnus.com>, 1998.
 
@@ -22,8 +22,7 @@
 #include <signal.h>
 
 int
-sigrelse (sig)
-     int sig;
+sigrelse (int sig)
 {
   sigset_t set;
 
