@@ -1,4 +1,4 @@
-/* Copyright (C) 1991-2013 Free Software Foundation, Inc.
+/* Copyright (C) 1991-2017 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
 #include <signal.h>
 
 int
-__sigsetmask (mask)
-     int mask;
+__sigsetmask (int mask)
 {
   __set_errno (ENOSYS);
   return -1;
