@@ -28,7 +28,7 @@ main (void)
       return 1;
     }
   for (i = 0; i < 1000; ++i)
-    fprintf (in, "%u\n", i);
+    fprintf (in, "%Zu\n", i);
 
   out = fopen (outname, "w");
   if (out == NULL)
@@ -56,6 +56,10 @@ main (void)
   puts ("There should be no further output from this test.");
   fflush (stdout);
 
+  /* We must remove this entry to assure the `cmp' binary does not use
+     the perhaps incompatible new shared libraries.  */
+  unsetenv ("LD_LIBRARY_PATH");
+
   asprintf (&printbuf, "cmp %s %s", inname, outname);
   result = system (printbuf);
   remove (inname);
