@@ -1,4 +1,4 @@
-/* Copyright (C) 1995-2013 Free Software Foundation, Inc.
+/* Copyright (C) 1995-2017 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
    Contributed by Ulrich Drepper <drepper@gnu.ai.mit.edu>, August 1995.
 
@@ -20,8 +20,7 @@
 
 
 void
-srand48 (seedval)
-     long seedval;
+srand48 (long seedval)
 {
   (void) __srand48_r (seedval, &__libc_drand48_data);
 }
