@@ -1,5 +1,4 @@
-/* Copyright (C) 1991,1992,1996,1997,1999,2000,2001,2009,2010,2012
-   Free Software Foundation, Inc.
+/* Copyright (C) 1991-2017 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -20,9 +19,9 @@
 #define	_STRINGS_H	1
 
 /* We don't need and should not read this file if <string.h> was already
-   read. The one exception being that if __USE_BSD isn't defined, then
+   read. The one exception being that if __USE_MISC isn't defined, then
    these aren't defined in string.h, so we need to define them here.  */
-#if !defined _STRING_H || !defined __USE_BSD
+#if !defined _STRING_H || !defined __USE_MISC
 
 # include <features.h>
 # define __need_size_t
@@ -137,4 +136,12 @@ __END_DECLS
 
 #endif	/* string.h  */
 
+#if __GNUC_PREREQ (3,4) && __USE_FORTIFY_LEVEL > 0 \
+    && defined __fortify_function
+/* Functions with security checks.  */
+# if defined __USE_MISC || !defined __USE_XOPEN2K8
+#  include <bits/strings_fortified.h>
+# endif
+#endif
+
 #endif	/* strings.h  */
