@@ -1,5 +1,5 @@
 /* Return arc sine of complex float value.
-   Copyright (C) 2004-2015 Free Software Foundation, Inc.
+   Copyright (C) 2004-2017 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -24,14 +24,18 @@
 
 #undef __casinf
 #undef casinf
-#define __casinf internal_casinf
 
 static _Complex float internal_casinf (_Complex float x);
 
-#include <math/s_casinf.c>
-#include "cfloat-compat.h"
+#define M_DECL_FUNC(f) internal_casinf
+#include <math-type-macros-float.h>
 
-#undef __casinf
+/* Disable any aliasing from base template.  */
+#undef declare_mgen_alias
+#define declare_mgen_alias(__to, __from)
+
+#include <math/s_casin_template.c>
+#include "cfloat-compat.h"
 
 c1_cfloat_rettype
 __c1_casinf (c1_cfloat_decl (x))
