@@ -29,18 +29,19 @@ static char rcsid[] = "$NetBSD: $";
  *                := signl(x)*log1pl(|x| + x^2/(1 + sqrtl(1+x^2)))
  */
 
+#include <float.h>
 #include <math.h>
 #include <math_private.h>
 
-static const long double
-  one = 1.0L,
-  ln2 = 6.931471805599453094172321214581765681e-1L,
-  huge = 1.0e+4900L;
+static const _Float128
+  one = 1,
+  ln2 = L(6.931471805599453094172321214581765681e-1),
+  huge = L(1.0e+4900);
 
-long double
-__asinhl (long double x)
+_Float128
+__asinhl (_Float128 x)
 {
-  long double t, w;
+  _Float128 t, w;
   int32_t ix, sign;
   ieee854_long_double_shape_type u;
 
@@ -51,6 +52,7 @@ __asinhl (long double x)
     return x + x;		/* x is inf or NaN */
   if (ix < 0x3fc70000)
     {				/* |x| < 2^ -56 */
+      math_check_force_underflow (x);
       if (huge + x > one)
 	return x;		/* return x inexact except 0 */
     }
