@@ -1,4 +1,4 @@
-/* Copyright (C) 1991-2014 Free Software Foundation, Inc.
+/* Copyright (C) 1991-2017 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -20,8 +20,7 @@
 
 /* Set the file creation mask to MASK, returning the old mask.  */
 mode_t
-__umask (mask)
-     mode_t mask;
+__umask (mode_t mask)
 {
   mode_t omask;
   mask &= 0777;
