@@ -1,5 +1,5 @@
 /* Configuration for math tests.  MIPS version.
-   Copyright (C) 2013-2015 Free Software Foundation, Inc.
+   Copyright (C) 2013-2017 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -35,4 +35,10 @@
 # define EXCEPTION_TESTS_long_double	0
 #endif
 
+/* NaN payload preservation when converting a signaling NaN to quiet
+   is only required in NAN2008 mode.  */
+#ifndef __mips_nan2008
+# define SNAN_TESTS_PRESERVE_PAYLOAD	0
+#endif
+
 #include_next <math-tests.h>
