@@ -1,5 +1,4 @@
-/* Copyright (C) 1991,1993,1995,1996,1998,2002,2003, 2007
-   Free Software Foundation, Inc.
+/* Copyright (C) 1991-2017 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -44,7 +43,7 @@ __closedir (DIR *dirp)
 
   fd = dirp->fd;
 
-#ifndef NOT_IN_libc
+#if IS_IN (libc)
   __libc_lock_fini (dirp->lock);
 #endif
 
