@@ -1,4 +1,4 @@
-/* Copyright (C) 2014-2016 Free Software Foundation, Inc.
+/* Copyright (C) 2014-2017 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -26,4 +26,4 @@
 
 extern __typeof (strcat) __strcat_ppc attribute_hidden;
 
-#include <sysdeps/powerpc/strcat.c>
+#include <string/strcat.c>
