@@ -1,4 +1,4 @@
-/* Copyright (C) 2002-2014 Free Software Foundation, Inc.
+/* Copyright (C) 2002-2017 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
    Contributed by Ulrich Drepper <drepper@redhat.com>, 2002.
 
@@ -19,12 +19,11 @@
 #include <pthread.h>
 #include <stdio.h>
 #include <libio.h>
-#include <bits/stdio-lock.h>
+#include <stdio-lock.h>
 
 
 void
-__flockfile (stream)
-     FILE *stream;
+__flockfile (FILE *stream)
 {
   _IO_lock_lock (*stream->_lock);
 }
