@@ -1,5 +1,5 @@
 /* Definitions for S/390 syntax variations.
-   Copyright (C) 1992, 1994, 1995, 1997, 2000 Free Software Foundation, Inc.
+   Copyright (C) 1992-2017 Free Software Foundation, Inc.
    This file is part of the GNU C Library.  Its master source is NOT part of
    the C library, however.  The master source lives in the GNU MP Library.
 
@@ -14,28 +14,11 @@
    Lesser General Public License for more details.
 
    You should have received a copy of the GNU Lesser General Public
-   License along with the GNU C Library; if not, write to the Free
-   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-   02111-1307 USA.  */
+   License along with the GNU C Library; if not, see
+   <http://www.gnu.org/licenses/>.  */
 
 #undef ALIGN
-#if defined NOLOG_ALIGN || defined HAVE_ELF
-# define ALIGN(log) .align 1<<log
-#else
-# define ALIGN(log) .align log
-#endif
+#define ALIGN(log) .align 1<<log
 
 #undef L
-#ifdef __ELF__
-# ifdef __STDC__
-#  define L(body) .L##body
-# else
-#  define L(body) .L/**/body
-# endif
-#else
-# ifdef __STDC__
-#  define L(body) L##body
-# else
-#  define L(body) L/**/body
-# endif
-#endif
+#define L(body) .L##body
