@@ -1,5 +1,5 @@
 /* Install given floating-point environment.
-   Copyright (C) 2000-2014 Free Software Foundation, Inc.
+   Copyright (C) 2000-2017 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
    Contributed by Denis Joseph Barrow (djbarrow@de.ibm.com).
 
@@ -25,19 +25,17 @@
 #include <unistd.h>
 
 int
-fesetenv (const fenv_t *envp)
+__fesetenv (const fenv_t *envp)
 {
   fenv_t env;
 
   if (envp == FE_DFL_ENV)
     {
       env.__fpc = _FPU_DEFAULT;
-      env.__ieee_instruction_pointer = 0;
     }
   else if (envp == FE_NOMASK_ENV)
     {
       env.__fpc = FPC_EXCEPTION_MASK;
-      env.__ieee_instruction_pointer = 0;
     }
   else
     env = (*envp);
@@ -47,4 +45,6 @@ fesetenv (const fenv_t *envp)
   /* Success.  */
   return 0;
 }
-libm_hidden_def (fesetenv)
+libm_hidden_def (__fesetenv)
+weak_alias (__fesetenv, fesetenv)
+libm_hidden_weak (fesetenv)
