@@ -1,4 +1,4 @@
-/* Copyright (C) 2011-2015 Free Software Foundation, Inc.
+/* Copyright (C) 2011-2017 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
    Contributed by Chris Metcalf <cmetcalf@tilera.com>, 2011.
 
@@ -21,20 +21,20 @@
 #include <errno.h>
 #include <sysdep.h>
 
-#ifndef MMAP_PAGE_SHIFT
-#define MMAP_PAGE_SHIFT 12
+#ifndef MMAP_PAGE_UNIT
+# define MMAP_PAGE_UNIT 4096UL
 #endif
 
 __ptr_t
 __mmap (__ptr_t addr, size_t len, int prot, int flags, int fd, off_t offset)
 {
-  if (offset & ((1 << MMAP_PAGE_SHIFT) - 1))
+  if (offset & (MMAP_PAGE_UNIT - 1))
     {
       __set_errno (EINVAL);
       return MAP_FAILED;
     }
   return (__ptr_t) INLINE_SYSCALL (mmap2, 6, addr, len, prot, flags, fd,
-                                   offset >> MMAP_PAGE_SHIFT);
+                                   offset / MMAP_PAGE_UNIT);
 }
 
 weak_alias (__mmap, mmap)
