@@ -1,5 +1,5 @@
 /* Definition of `struct stat' used in the kernel.
-   Copyright (C) 1997, 2000, 2002 Free Software Foundation, Inc.
+   Copyright (C) 1997-2017 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -31,9 +31,9 @@ struct kernel_stat
     struct timespec st_atim;
     struct timespec st_mtim;
     struct timespec st_ctim;
-    unsigned long int __unused4;
+    unsigned long int __glibc_reserved4;
 #define _HAVE___UNUSED4
-    unsigned long int __unused5;
+    unsigned long int __glibc_reserved5;
 #define _HAVE___UNUSED5
   };
 
@@ -46,3 +46,6 @@ struct kernel_stat
 #define _HAVE_STAT64___UNUSED5
 #define _HAVE_STAT64___PAD2
 #define _HAVE_STAT64_NSEC
+
+#define XSTAT_IS_XSTAT64 0
+#define STATFS_IS_STATFS64 0
