@@ -1,4 +1,4 @@
-/* Copyright (C) 2001-2015 Free Software Foundation, Inc.
+/* Copyright (C) 2001-2017 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
    Contributed by Martin Schwidefsky (schwidefsky@de.ibm.com).
 
@@ -30,11 +30,11 @@
    user context. The stack looks like this:
 	   size                         offset
     %r15 ->    +-----------------------+
-	     4 | back chain (zero)     |  0
-	     4 | reserved              |  4
-	    88 | save area for (*func) |  8
+	     8 | back chain (zero)     |  0
+	     8 | reserved              |  8
+	   144 | save area for (*func) | 16
 	       +-----------------------+
-	     n | overflow parameters   | 96
+	     n | overflow parameters   | 160
 	       +-----------------------+
    The registers are set up like this:
      %r2-%r6: parameters 1 to 5
@@ -46,7 +46,7 @@
 
    The trampoline looks like this:
      basr  %r14,%r7
-     lr    %r2,%r8
+     lgr   %r2,%r8
      br    %r9.  */
 
 void
@@ -77,7 +77,7 @@ __makecontext (ucontext_t *ucp, void (*func) (void), int argc, ...)
   va_end (ap);
 
   /* Make room for the save area and set the backchain.  */
-  sp -= 24;
+  sp -= 20;
   *sp = 0;
 
   /* Pass (*func) to __makecontext_ret in %r7.  */
