@@ -1,4 +1,4 @@
-/* Copyright (C) 1998-2013 Free Software Foundation, Inc.
+/* Copyright (C) 1998-2017 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
    Contributed by Ulrich Drepper <drepper@cygnus.com>, 1998.
 
@@ -18,12 +18,13 @@
 
 #include <wchar.h>
 
+#ifdef WCSNLEN
+# define __wcsnlen WCSNLEN
+#endif
 
-/* Copy SRC to DEST.  */
+/* Return length of string S at most maxlen.  */
 size_t
-__wcsnlen (s, maxlen)
-     const wchar_t *s;
-     size_t maxlen;
+__wcsnlen (const wchar_t *s, size_t maxlen)
 {
   size_t len = 0;
 
@@ -44,4 +45,6 @@ __wcsnlen (s, maxlen)
 
   return len;
 }
+#ifndef WCSNLEN
 weak_alias (__wcsnlen, wcsnlen)
+#endif
