@@ -1,4 +1,4 @@
-/* Copyright (C) 1996,97,99,2002 Free Software Foundation, Inc.
+/* Copyright (C) 1996-2017 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
    Contributed by Ulrich Drepper <drepper@gnu.org>, 1996.
 
@@ -18,14 +18,14 @@
 
 #include <wchar.h>
 
+#ifdef WMEMSET
+# define __wmemset WMEMSET
+#endif
 
 wchar_t *
-wmemset (s, c, n)
-     wchar_t *s;
-     wchar_t c;
-     size_t n;
+__wmemset (wchar_t *s, wchar_t c, size_t n)
 {
-  register wchar_t *wp = s;
+  wchar_t *wp = s;
 
   while (n >= 4)
     {
@@ -52,4 +52,6 @@ wmemset (s, c, n)
 
   return s;
 }
-libc_hidden_def (wmemset)
+libc_hidden_def (__wmemset)
+weak_alias (__wmemset, wmemset)
+libc_hidden_weak (wmemset)
